@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Jolla Ltd.
+** Copyright (C) 2013-2014 Jolla Ltd.
 ** Contact: lorn.potter@jollamobile.com
 **
 ** GNU Lesser General Public License Usage
@@ -18,25 +18,15 @@
 
 #include "qofono_global.h"
 
-#if QT_VERSION < 0x050000
-#include <QtDeclarative/qdeclarative.h>
-#include <QtDeclarative/QDeclarativeExtensionPlugin>
-class QOFONOSHARED_EXPORT QOfonoDeclarativePlugin : public QDeclarativeExtensionPlugin
-#else
 #include <QtQml/qqmlextensionplugin.h>
 #include <QtQml/qqml.h>
 class QOFONOSHARED_EXPORT QOfonoDeclarativePlugin : public QQmlExtensionPlugin
-#endif
 {
     Q_OBJECT
-#if QT_VERSION >= 0x050000
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface" FILE "plugin.json")
-#endif
 public:
     void registerTypes(const char *uri);
-#if QT_VERSION < 0x050000
-    void initializeEngine(QDeclarativeEngine *engine, const char *uri);
-#endif
+    static void registerTypes(const char *uri, int major, int minor);
 };
 
 #endif // QOFONODECLARATIVEPLUGIN_H
