@@ -1,7 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013-2014 Jolla Ltd.
-** Contact: lorn.potter@jollamobile.com
+** Copyright (C) 2013-2022 Jolla Ltd.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -59,6 +58,10 @@ public:
     QString filter() const;
     void setFilter(const QString &filter);
 
+    // Remember to keep a QSharedPointer to QOfonoConnectionManager, otherwise
+    // it may be destroyed.
+    static QSharedPointer<QOfonoConnectionManager> instance(const QString &path);
+
 Q_SIGNALS:
     void attachedChanged(bool value);
     void bearerChanged(const QString &bearer);
@@ -71,14 +74,17 @@ Q_SIGNALS:
     void contextsChanged(const QStringList &contexts);
     void filterChanged(const QString &filter);
 
-public slots:
+public Q_SLOTS:
     void deactivateAll();
     void addContext(const QString &type);
     void removeContext(const QString &path);
+    void resetContexts(); // Since 0.110
 
-private slots:
+private Q_SLOTS:
     void onAddContextFinished(QDBusPendingCallWatcher *watch);
     void onRemoveContextFinished(QDBusPendingCallWatcher *watch);
+    void onDeactivateAllFinished(QDBusPendingCallWatcher *watch);
+    void onResetContextFinished(QDBusPendingCallWatcher *watch);
     void onGetContextsFinished(QDBusPendingCallWatcher *watch);
     void onContextAdded(const QDBusObjectPath &path, const QVariantMap &propertyMap);
     void onContextRemoved(const QDBusObjectPath &path);
