@@ -82,7 +82,7 @@ Q_SIGNALS:
 private:
     static Error errorNameToEnum(const QString &errorName);
 
-private slots:
+private Q_SLOTS:
     void onRegisterFinished(QDBusPendingCallWatcher *call);
 
 protected:
