@@ -29,6 +29,7 @@ class QOFONOSHARED_EXPORT QOfonoRadioSettings : public QOfonoModemInterface
     Q_OBJECT
     Q_PROPERTY(QString modemPath READ modemPath WRITE setModemPath NOTIFY modemPathChanged)
     Q_PROPERTY(QString technologyPreference READ technologyPreference WRITE setTechnologyPreference NOTIFY technologyPreferenceChanged)
+    Q_PROPERTY(QStringList availableTechnologies READ availableTechnologies NOTIFY availableTechnologiesChanged)
     Q_PROPERTY(QString gsmBand READ gsmBand WRITE setGsmBand NOTIFY gsmBandChanged)
     Q_PROPERTY(QString umtsBand READ umtsBand WRITE setUmtsBand NOTIFY umtsBandChanged)
     Q_PROPERTY(bool fastDormancy READ fastDormancy WRITE setFastDormancy NOTIFY fastDormancyChanged)
@@ -43,6 +44,8 @@ public:
     QString technologyPreference() const;
     void setTechnologyPreference(const QString &preference);
 
+    QStringList availableTechnologies() const;
+
     QString gsmBand() const;
     void setGsmBand(const QString &gsmBand);
 
@@ -56,6 +59,7 @@ public:
 
 Q_SIGNALS:
     void technologyPreferenceChanged(const QString &preference);
+    void availableTechnologiesChanged(const QStringList &technologies);
     void gsmBandChanged(const QString &gsmBand);
     void umtsBandChanged(const QString &umtsBand);
     void fastDormancyChanged(bool fastDormancy);
