@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013-2014 Jolla Ltd.
+** Copyright (C) 2013-2016 Jolla Ltd.
 ** Contact: lorn.potter@jollamobile.com
 **
 ** GNU Lesser General Public License Usage
@@ -33,6 +33,7 @@ class QOFONOSHARED_EXPORT QOfonoSimManager : public QOfonoModemInterface
     Q_PROPERTY(QString subscriberIdentity READ subscriberIdentity NOTIFY subscriberIdentityChanged)
     Q_PROPERTY(QString mobileCountryCode READ mobileCountryCode NOTIFY mobileCountryCodeChanged)
     Q_PROPERTY(QString mobileNetworkCode READ mobileNetworkCode NOTIFY mobileNetworkCodeChanged)
+    Q_PROPERTY(QString serviceProviderName READ serviceProviderName NOTIFY serviceProviderNameChanged)
     Q_PROPERTY(QStringList subscriberNumbers READ subscriberNumbers WRITE setSubscriberNumbers NOTIFY subscriberNumbersChanged)
     Q_PROPERTY(QVariantMap serviceNumbers READ serviceNumbers NOTIFY serviceNumbersChanged)
     Q_PROPERTY(PinType pinRequired READ pinRequired NOTIFY pinRequiredChanged)
@@ -44,6 +45,8 @@ class QOFONOSHARED_EXPORT QOfonoSimManager : public QOfonoModemInterface
     Q_PROPERTY(bool barredDialing READ barredDialing NOTIFY barredDialingChanged)
 
 public:
+    class SharedPointer;
+
     enum Error {
         NoError,
         NotImplementedError,
@@ -82,6 +85,7 @@ public:
     QString subscriberIdentity() const;
     QString mobileCountryCode() const;
     QString mobileNetworkCode() const;
+    QString serviceProviderName() const;
     QStringList subscriberNumbers() const;
     QVariantMap serviceNumbers() const; //
     PinType pinRequired() const;
@@ -98,6 +102,7 @@ Q_SIGNALS:
     void subscriberIdentityChanged(const QString &imsi);
     void mobileCountryCodeChanged(const QString &mcc);
     void mobileNetworkCodeChanged(const QString &mnc);
+    void serviceProviderNameChanged(const QString &spn);
     void subscriberNumbersChanged(const QStringList &msisdns);
     void serviceNumbersChanged(const QVariantMap &sdns);
     void pinRequiredChanged(int pinType);
@@ -114,7 +119,7 @@ Q_SIGNALS:
     void lockPinComplete(QOfonoSimManager::Error error, const QString &errorString);
     void unlockPinComplete(QOfonoSimManager::Error error, const QString &errorString);
 
-public slots:
+public Q_SLOTS:
     void changePin(QOfonoSimManager::PinType pinType, const QString &oldpin, const QString &newpin);
     void enterPin(QOfonoSimManager::PinType pinType, const QString &pin);
     void resetPin(QOfonoSimManager::PinType pinType, const QString &puk, const QString &newpin);
@@ -139,7 +144,7 @@ protected:
     QVariant convertProperty(const QString &property, const QVariant &value);
     void propertyChanged(const QString &property, const QVariant &value);
 
-private slots:
+private Q_SLOTS:
     void changePinCallFinished(QDBusPendingCallWatcher *call);
     void enterPinCallFinished(QDBusPendingCallWatcher *call);
     void resetPinCallFinished(QDBusPendingCallWatcher *call);
@@ -147,4 +152,10 @@ private slots:
     void unlockPinCallFinished(QDBusPendingCallWatcher *call);
 };
 
+// Unlike the default QSharedPointer, deletes QOfonoSimManager with deleteLater
+class QOFONOSHARED_EXPORT QOfonoSimManager::SharedPointer : public QSharedPointer<QOfonoSimManager> {
+public:
+    SharedPointer(QOfonoSimManager * ptr = NULL) : QSharedPointer<QOfonoSimManager>(ptr, &QObject::deleteLater) {}
+};
+
 #endif // QOFONOSimManager_H
